@@ -49,18 +49,21 @@ updateAceEditor <- function(
   autoCompleters = c("snippet", "text", "keyword", "static", "rlang"),
   autoCompleteList = NULL
 ) {
-
+  
   if (missing(session) || missing(editorId)) {
     stop("Must provide both a session and an editorId to update Ace editor settings")
   }
-  if(!all(autoComplete %in% c("disabled", "enabled", "live")))
+  if (!all(autoComplete %in% c("disabled", "enabled", "live"))) {
     stop("updateAceEditor: Incorrectly formatted autoComplete parameter")
-  if(!all(border %in% c("normal", "alert", "flash")))
+  }
+  if (!all(border %in% c("normal", "alert", "flash"))) {
     stop("updateAceEditor: Incorrectly formatted border parameter")
-  if(!is.empty(autoCompleters) && !all(autoCompleters %in% c("snippet", "text", "keyword", "static", "rlang")))
+  }
+  if (!is.empty(autoCompleters) && !all(autoCompleters %in% c("snippet", "text", "keyword", "static", "rlang"))) {
     stop("updateAceEditor: Incorrectly formatted autoCompleters parameter")
+  }
 
-  theList <- list(id = editorId)
+  theList <- list(id = session$ns(editorId))
 
   if (!missing(value)) theList["value"] <- value
   if (!missing(theme)) theList["theme"] <- theme
@@ -96,4 +99,4 @@ updateAceEditor <- function(
   }
 
   session$sendCustomMessage("shinyAce", theList)
-}
+}
\ No newline at end of file
